@@ -2,7 +2,7 @@
  * VampirTrace
  * http://www.tu-dresden.de/zih/vampirtrace
  *
- * Copyright (c) 2005-2012, ZIH, TU Dresden, Federal Republic of Germany
+ * Copyright (c) 2005-2013, ZIH, TU Dresden, Federal Republic of Germany
  *
  * Copyright (c) 1998-2005, Forschungszentrum Juelich, Juelich Supercomputing
  *                          Centre, Federal Republic of Germany
@@ -13,8 +13,6 @@
 #ifndef _VT_UNIFY_HOOKS_BASE_H_
 #define _VT_UNIFY_HOOKS_BASE_H_
 
-#include "config.h"
-
 #include "vt_unify_hooks.h"
 
 //
@@ -37,8 +35,8 @@ private:
    // trigger phase hook
    void triggerPhaseHook( const HooksC::PhaseTypeT & phase )
    {
-      assert( m_phaseMethods.size() > (uint32_t)phase );
-      assert( m_phaseMethods[phase] != 0 );
+      vt_assert( m_phaseMethods.size() > (uint32_t)phase );
+      vt_assert( m_phaseMethods[phase] != 0 );
 
       ( this->*( m_phaseMethods[phase] ) )();
    }
@@ -47,8 +45,8 @@ private:
    void triggerReadRecordHook( const HooksC::RecordTypeT & rectype,
                                HooksC::VaArgsT & args )
    {
-      assert( m_readRecHookMethods.size() > (uint32_t)rectype );
-      assert( m_readRecHookMethods[rectype] != 0 );
+      vt_assert( m_readRecHookMethods.size() > (uint32_t)rectype );
+      vt_assert( m_readRecHookMethods[rectype] != 0 );
 
       ( this->*( m_readRecHookMethods[rectype] ) )( args );
    }
@@ -57,8 +55,8 @@ private:
    void triggerWriteRecordHook( const HooksC::RecordTypeT & rectype,
                                 HooksC::VaArgsT & args )
    {
-      assert( m_writeRecHookMethods.size() > (uint32_t)rectype );
-      assert( m_writeRecHookMethods[rectype] != 0 );
+      vt_assert( m_writeRecHookMethods.size() > (uint32_t)rectype );
+      vt_assert( m_writeRecHookMethods[rectype] != 0 );
 
       ( this->*( m_writeRecHookMethods[rectype] ) )( args );
    }
@@ -221,6 +219,17 @@ private:
    virtual void readRecHook_EventComment( HooksC::VaArgsT & args ) { (void)args; }
    virtual void writeRecHook_EventComment( HooksC::VaArgsT & args ) { (void)args; }
 
+   // snapshot records
+   //
+
+   virtual void writeRecHook_EnterSnapshot( HooksC::VaArgsT & args ) { (void)args; }
+   virtual void writeRecHook_SendSnapshot( HooksC::VaArgsT & args ) { (void)args; }
+   virtual void writeRecHook_OpenFileSnapshot( HooksC::VaArgsT & args ) { (void)args; }
+   virtual void writeRecHook_BeginFileOpSnapshot( HooksC::VaArgsT & args ) { (void)args; }
+   virtual void writeRecHook_BeginCollOpSnapshot( HooksC::VaArgsT & args ) { (void)args; }
+   virtual void writeRecHook_CollOpCountSnapshot( HooksC::VaArgsT & args ) { (void)args; }
+   virtual void writeRecHook_CounterSnapshot( HooksC::VaArgsT & args ) { (void)args; }
+
    // generic hook
    virtual void genericHook( const uint32_t & id, HooksC::VaArgsT & args ) { (void)args; }
 
