@@ -66,7 +66,7 @@ enum {
 
     OMPI_ERR_REQUEST                = OMPI_ERR_BASE - 1,
     OMPI_ERR_RMA_SYNC               = OMPI_ERR_BASE - 2,
-    OMPI_ERR_RMA_SHARED             = OMPI_ERR_BASE - 3,
+    OMPI_ERR_RMA_SHARED             = OMPI_ERR_BASE - 3
 };
 
 #define OMPI_ERR_MAX                    (OMPI_ERR_BASE - 100)
