@@ -50,6 +50,7 @@ mca_mtl_mxm_module_t ompi_mtl_mxm = {
 };
 
 
+#if MXM_API < MXM_VERSION(2,0)
 static uint32_t ompi_mtl_mxm_get_job_id(void)
 {
     uint8_t  unique_job_key[16];
@@ -81,6 +82,7 @@ static uint32_t ompi_mtl_mxm_get_job_id(void)
 
     return job_key;
 }
+#endif
 
 int ompi_mtl_mxm_progress(void);
 #if MXM_API >= MXM_VERSION(2,0)
@@ -125,7 +127,7 @@ static int ompi_mtl_mxm_get_ep_address(void **address_p, size_t *address_len_p)
 
     err = mxm_ep_get_address(ompi_mtl_mxm.ep, *address_p, address_len_p);
     if (MXM_OK != err) {
-        opal_show_help("help-mtl-mxm.txt", "unable to extract endpoint address",
+        opal_show_help("help-mtl-mxm.txt", "unable to extract endpoint ptl address",
                        true, mxm_error_string(err));
         return OMPI_ERROR;
     }
@@ -281,12 +283,15 @@ int ompi_mtl_mxm_module_init(void)
 
     mxlr = 0;
     lr = -1;
+    jobid = 0;
 
+#if MXM_API < MXM_VERSION(2,0)
     jobid = ompi_mtl_mxm_get_job_id();
     if (0 == jobid) {
     	MXM_ERROR("Failed to generate jobid");
     	return OMPI_ERROR;
     }
+#endif
 
     if (NULL == (procs = ompi_proc_world(&totps))) {
         MXM_ERROR("Unable to obtain process list");
@@ -479,6 +484,12 @@ int ompi_mtl_mxm_add_procs(struct mca_mtl_base_module_t *mtl, size_t nprocs,
 
 #endif
 
+#if MXM_API >= MXM_VERSION(3,1)
+    if (ompi_mtl_mxm.bulk_connect) {
+        mxm_ep_wireup(ompi_mtl_mxm.ep);
+    }
+#endif
+
     rc = OMPI_SUCCESS;
 
 bail:
@@ -494,18 +505,23 @@ int ompi_mtl_mxm_del_procs(struct mca_mtl_base_module_t *mtl, size_t nprocs,
 {
     size_t i;
 
+#if MXM_API >= MXM_VERSION(3,1)
+    if (ompi_mtl_mxm.bulk_disconnect &&
+            nprocs == ompi_comm_size(&ompi_mpi_comm_world.comm)) {
+        mxm_ep_powerdown(ompi_mtl_mxm.ep);
+    }
+#endif
+
     /* XXX: Directly accessing the obj_reference_count is an abstraction
      * violation of the object system. We know this needs to be fixed, but
      * are deferring the fix to a later time as it involves a design issue
      * in the way we handle endpoints as objects
      */
     for (i = 0; i < nprocs; ++i) {
-        if (((opal_object_t*)procs[i])->obj_reference_count == 1) {
-            mca_mtl_mxm_endpoint_t *endpoint = (mca_mtl_mxm_endpoint_t*)
-                            procs[i]->proc_endpoints[OMPI_PROC_ENDPOINT_TAG_MTL];
-            mxm_ep_disconnect(endpoint->mxm_conn);
-            OBJ_RELEASE(endpoint);
-        }
+        mca_mtl_mxm_endpoint_t *endpoint = (mca_mtl_mxm_endpoint_t*)
+            procs[i]->proc_endpoints[OMPI_PROC_ENDPOINT_TAG_MTL];
+        mxm_ep_disconnect(endpoint->mxm_conn);
+        OBJ_RELEASE(endpoint);
     }
     return OMPI_SUCCESS;
 }
