@@ -1,3 +1,25 @@
+/*
+ * Copyright (c) 2004-2007 The Trustees of Indiana University and Indiana
+ *                         University Research and Technology
+ *                         Corporation.  All rights reserved.
+ * Copyright (c) 2004-2005 The University of Tennessee and The University
+ *                         of Tennessee Research Foundation.  All rights
+ *                         reserved.
+ * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart, 
+ *                         University of Stuttgart.  All rights reserved.
+ * Copyright (c) 2004-2005 The Regents of the University of California.
+ *                         All rights reserved.
+ * $COPYRIGHT$
+ * 
+ * Additional copyrights may follow
+ * 
+ * $HEADER$
+ */
+/*
+ * This file is almost a complete re-write for Open MPI compared to the
+ * original mpiJava package. Its license and copyright are listed below.
+ * See <path to ompi/mpi/java/README> for more information.
+ */
 /*
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -50,19 +72,23 @@ protected Intracomm(long handle)
     super(handle);
 }
 
+protected Intracomm(long[] commRequest)
+{
+    super(commRequest);
+}
+
 /**
- * Duplicate this communicator.
- * <p>Java binding of the MPI operation {@code MPI_COMM_DUP}.
- * <p>The new communicator is "congruent" to the old one,
- *    but has a different context.
+ * Duplicates this communicator.
+ * <p>Java binding of {@code MPI_COMM_DUP}.
+ * <p>It is recommended to use {@link #dup} instead of {@link #clone}
+ * because the last can't throw an {@link mpi.MPIException}.
  * @return copy of this communicator
  */
 @Override public Intracomm clone()
 {
     try
     {
-        MPI.check();
-        return new Intracomm(dup());
+        return dup();
     }
     catch(MPIException e)
     {
@@ -70,6 +96,32 @@ protected Intracomm(long handle)
     }
 }
 
+/**
+ * Duplicates this communicator.
+ * <p>Java binding of {@code MPI_COMM_DUP}.
+ * @return copy of this communicator
+ * @throws MPIException
+ */
+@Override public Intracomm dup() throws MPIException
+{
+    MPI.check();
+    return new Intracomm(dup(handle));
+}
+
+/**
+ * Duplicates this communicator.
+ * <p>Java binding of {@code MPI_COMM_IDUP}.
+ * <p>The new communicator can't be used before the operation completes.
+ * The request object must be obtained calling {@link #getRequest}.
+ * @return copy of this communicator
+ * @throws MPIException
+ */
+@Override public Intracomm iDup() throws MPIException
+{
+    MPI.check();
+    return new Intracomm(iDup(handle));
+}
+
 /**
  * Partition the group associated with this communicator and create
  * a new communicator within each subgroup.
@@ -299,13 +351,13 @@ public final void scan(Object sendbuf, Object recvbuf,
 
     if(sendbuf instanceof Buffer && !(sdb = ((Buffer)sendbuf).isDirect()))
     {
-        sendoff = ((Buffer)sendbuf).arrayOffset();
+        sendoff = type.getOffset(sendbuf);
         sendbuf = ((Buffer)sendbuf).array();
     }
 
     if(recvbuf instanceof Buffer && !(rdb = ((Buffer)recvbuf).isDirect()))
     {
-        recvoff = ((Buffer)recvbuf).arrayOffset();
+        recvoff = type.getOffset(recvbuf);
         recvbuf = ((Buffer)recvbuf).array();
     }
 
@@ -334,7 +386,7 @@ public final void scan(Object recvbuf, int count, Datatype type, Op op)
 
     if(recvbuf instanceof Buffer && !(rdb = ((Buffer)recvbuf).isDirect()))
     {
-        recvoff = ((Buffer)recvbuf).arrayOffset();
+        recvoff = type.getOffset(recvbuf);
         recvbuf = ((Buffer)recvbuf).array();
     }
 
@@ -423,13 +475,13 @@ public final void exScan(Object sendbuf, Object recvbuf,
 
     if(sendbuf instanceof Buffer && !(sdb = ((Buffer)sendbuf).isDirect()))
     {
-        sendoff = ((Buffer)sendbuf).arrayOffset();
+        sendoff = type.getOffset(sendbuf);
         sendbuf = ((Buffer)sendbuf).array();
     }
 
     if(recvbuf instanceof Buffer && !(rdb = ((Buffer)recvbuf).isDirect()))
     {
-        recvoff = ((Buffer)recvbuf).arrayOffset();
+        recvoff = type.getOffset(recvbuf);
         recvbuf = ((Buffer)recvbuf).array();
     }
 
@@ -458,7 +510,7 @@ public final void exScan(Object buf, int count, Datatype type, Op op)
 
     if(buf instanceof Buffer && !(db = ((Buffer)buf).isDirect()))
     {
-        off = ((Buffer)buf).arrayOffset();
+        off = type.getOffset(buf);
         buf = ((Buffer)buf).array();
     }
 
