@@ -267,6 +267,12 @@ static void proc_errors(int fd, short args, void *cbdata)
         goto cleanup;
     }
 
+        /* get the job object */
+    if (NULL == (jdata = orte_get_job_data_object(proc->jobid))) {
+        /* must already be complete */
+        goto cleanup;
+    }
+
     if (ORTE_PROC_STATE_COMM_FAILED == state) {
         /* if it is our own connection, ignore it */
         if (OPAL_EQUAL == orte_util_compare_name_fields(ORTE_NS_CMP_ALL, ORTE_PROC_MY_NAME, proc)) {
@@ -281,37 +287,86 @@ static void proc_errors(int fd, short args, void *cbdata)
                              "%s errmgr:default:orted daemon %s exited",
                              ORTE_NAME_PRINT(ORTE_PROC_MY_NAME),
                              ORTE_NAME_PRINT(proc)));
-        /* are any of my children still alive */
-        for (i=0; i < orte_local_children->size; i++) {
-            if (NULL != (child = (orte_proc_t*)opal_pointer_array_get_item(orte_local_children, i))) {
-                if (child->alive && child->state < ORTE_PROC_STATE_UNTERMINATED) {
-                    goto cleanup;
+        /* if we are using static ports, then it is possible that the HNP
+         * will not see this termination. So if the HNP didn't order us
+         * to terminate, then we should ensure it knows */
+        if (orte_static_ports && !orte_orteds_term_ordered) {
+            /* send an alert to the HNP */
+            alert = OBJ_NEW(opal_buffer_t);
+            /* pack update state command */
+            cmd = ORTE_PLM_UPDATE_PROC_STATE;
+            if (ORTE_SUCCESS != (rc = opal_dss.pack(alert, &cmd, 1, ORTE_PLM_CMD))) {
+                ORTE_ERROR_LOG(rc);
+                return;
+            }
+            /* get the proc_t */
+            if (NULL == (child = (orte_proc_t*)opal_pointer_array_get_item(jdata->procs, proc->vpid))) {
+                ORTE_ERROR_LOG(ORTE_ERR_NOT_FOUND);
+                ORTE_FORCED_TERMINATE(ORTE_ERROR_DEFAULT_EXIT_CODE);
+                goto cleanup;
+            }
+            /* set the exit code to reflect the problem */
+            child->exit_code = ORTE_ERR_COMM_FAILURE;
+            /* pack only the data for this daemon - have to start with the jobid
+             * so the receiver can unpack it correctly
+             */
+            if (ORTE_SUCCESS != (rc = opal_dss.pack(alert, &proc->jobid, 1, ORTE_JOBID))) {
+                ORTE_ERROR_LOG(rc);
+                return;
+            }
+
+            /* now pack the daemon's info */
+            if (ORTE_SUCCESS != (rc = pack_state_for_proc(alert, child))) {
+                ORTE_ERROR_LOG(rc);
+                return;
+            }
+            /* send it */
+            OPAL_OUTPUT_VERBOSE((5, orte_errmgr_base_framework.framework_output,
+                                 "%s errmgr:default_orted reporting lost connection to daemon %s",
+                                 ORTE_NAME_PRINT(ORTE_PROC_MY_NAME),
+                                 ORTE_NAME_PRINT(proc)));
+            if (0 > (rc = orte_rml.send_buffer_nb(ORTE_PROC_MY_HNP, alert,
+                                                  ORTE_RML_TAG_PLM,
+                                                  orte_rml_send_callback, NULL))) {
+                ORTE_ERROR_LOG(rc);
+                OBJ_RELEASE(alert);
+            }
+            /* continue on */
+            goto cleanup;
+        }
+
+        if (orte_orteds_term_ordered) {
+            /* are any of my children still alive */
+            for (i=0; i < orte_local_children->size; i++) {
+                if (NULL != (child = (orte_proc_t*)opal_pointer_array_get_item(orte_local_children, i))) {
+                    if (child->alive && child->state < ORTE_PROC_STATE_UNTERMINATED) {
+                        OPAL_OUTPUT_VERBOSE((5, orte_state_base_framework.framework_output,
+                                             "%s errmgr:default:orted[%s(%d)] proc %s is alive",
+                                             ORTE_NAME_PRINT(ORTE_PROC_MY_NAME),
+                                             __FILE__, __LINE__,
+                                             ORTE_NAME_PRINT(&child->name)));
+                        goto cleanup;
+                    }
                 }
             }
-        }
-        /* if all my routes and children are gone, then terminate
-           ourselves nicely (i.e., this is a normal termination) */
-        if (0 == orte_routed.num_routes()) {
-            OPAL_OUTPUT_VERBOSE((2, orte_errmgr_base_framework.framework_output,
-                                 "%s errmgr:default:orted all routes gone - exiting",
-                                 ORTE_NAME_PRINT(ORTE_PROC_MY_NAME)));
-            ORTE_ACTIVATE_JOB_STATE(NULL, ORTE_JOB_STATE_DAEMONS_TERMINATED);
-        } else {
-            OPAL_OUTPUT_VERBOSE((2, orte_errmgr_base_framework.framework_output,
-                                 "%s errmgr:default:orted not exiting, num_routes() == %d",
-                                 ORTE_NAME_PRINT(ORTE_PROC_MY_NAME),
-                                 (int)orte_routed.num_routes()));
+            /* if all my routes and children are gone, then terminate
+               ourselves nicely (i.e., this is a normal termination) */
+            if (0 == orte_routed.num_routes()) {
+                OPAL_OUTPUT_VERBOSE((2, orte_errmgr_base_framework.framework_output,
+                                     "%s errmgr:default:orted all routes gone - exiting",
+                                     ORTE_NAME_PRINT(ORTE_PROC_MY_NAME)));
+                ORTE_ACTIVATE_JOB_STATE(NULL, ORTE_JOB_STATE_DAEMONS_TERMINATED);
+            } else {
+                OPAL_OUTPUT_VERBOSE((2, orte_errmgr_base_framework.framework_output,
+                                     "%s errmgr:default:orted not exiting, num_routes() == %d",
+                                     ORTE_NAME_PRINT(ORTE_PROC_MY_NAME),
+                                     (int)orte_routed.num_routes()));
+            }
         }
         /* if not, then we can continue */
         goto cleanup;
     }
 
-    /* get the job object */
-    if (NULL == (jdata = orte_get_job_data_object(proc->jobid))) {
-        /* must already be complete */
-        goto cleanup;
-    }
-
     /* if there are no local procs for this job, we can
      * ignore this call
      */
@@ -457,10 +512,6 @@ static void proc_errors(int fd, short args, void *cbdata)
             ORTE_ERROR_LOG(rc);
             return;
         }
-        /* remove the child from our local array as it is no longer alive */
-        opal_pointer_array_set_item(orte_local_children, i, NULL);
-        /* Decrement the number of local procs */
-        jdata->num_local_procs--;
 
         OPAL_OUTPUT_VERBOSE((5, orte_errmgr_base_framework.framework_output,
                              "%s errmgr:default_orted reporting proc %s aborted to HNP (local procs = %d)",
@@ -468,15 +519,17 @@ static void proc_errors(int fd, short args, void *cbdata)
                              ORTE_NAME_PRINT(&child->name),
                              jdata->num_local_procs));
         
-        /* release the child object */
-        OBJ_RELEASE(child);
-
         /* send it */
         if (0 > (rc = orte_rml.send_buffer_nb(ORTE_PROC_MY_HNP, alert,
                                               ORTE_RML_TAG_PLM,
                                               orte_rml_send_callback, NULL))) {
             ORTE_ERROR_LOG(rc);
         }
+        /* if the proc still reports itself as alive, then we need
+         * to ensure the state machine sees it */
+        if (child->alive && child->waitpid_recvd) {
+            ORTE_ACTIVATE_PROC_STATE(&child->name, ORTE_PROC_STATE_WAITPID_FIRED);
+        }
         return;
     }
 
